"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskList = void 0;
const react_1 = __importDefault(require("react"));
const date_fns_1 = require("date-fns");
const taskify_shared_1 = require("@dotdev/taskify-shared");
const polaris_icons_1 = require("@shopify/polaris-icons");
const polaris_1 = require("@shopify/polaris");
const StatusBadge_1 = require("./StatusBadge");
const hooks_1 = require("../hooks");
const TaskList = ({ taskGroup, taskTypesFilterValues, }) => {
    const [selected, setSelected] = react_1.default.useState(0);
    const handleTabChange = react_1.default.useCallback((selectedTabIndex) => setSelected(selectedTabIndex), []);
    const selectedStatus = react_1.default.useMemo(() => "all" !== TABS[selected].id
        ? TABS[selected].id
        : undefined, [selected]);
    const [taskTypes, setTaskTypes] = react_1.default.useState([]);
    const { tasks, error, loading, nextPage, prevPage, hasNextPage, hasPrevPage, } = hooks_1.useTasks({
        taskTypes,
        status: selectedStatus,
    });
    const viewTask = hooks_1.useViewTask();
    const filters = react_1.default.useMemo(() => {
        if (!taskTypesFilterValues)
            return undefined;
        return [
            {
                key: "taskType",
                label: "Task type",
                shortcut: true,
                filter: (react_1.default.createElement(polaris_1.ChoiceList, { titleHidden: true, allowMultiple: true, title: "Task type", selected: taskTypes, onChange: (value) => {
                        setTaskTypes(value);
                    }, choices: taskTypesFilterValues.map((taskTypeFilterValue) => ({
                        label: taskTypeFilterValue,
                        value: taskTypeFilterValue,
                    })) })),
            },
        ];
    }, [taskTypesFilterValues, taskTypes]);
    const appliedFilters = react_1.default.useMemo(() => {
        const appliedFilters = [];
        if (0 < taskTypes.length) {
            appliedFilters.push({
                key: "taskType",
                onRemove: () => setTaskTypes([]),
                label: disambiguateLabel("taskType", taskTypes),
            });
        }
        return appliedFilters;
    }, [taskTypes]);
    return (react_1.default.createElement(polaris_1.Card, null,
        react_1.default.createElement(polaris_1.Tabs, { tabs: TABS, selected: selected, onSelect: handleTabChange },
            error && (react_1.default.createElement(polaris_1.Card.Section, null,
                react_1.default.createElement("div", { style: { paddingTop: "2rem", paddingBottom: "2rem" } },
                    react_1.default.createElement(polaris_1.Stack, { vertical: true, alignment: "center" },
                        react_1.default.createElement("span", { className: "large-icon" },
                            react_1.default.createElement(polaris_1.Icon, { source: polaris_icons_1.CircleAlertMajor, color: "critical" })),
                        react_1.default.createElement(polaris_1.DisplayText, { size: "small" }, error.message))))),
            react_1.default.createElement(polaris_1.ResourceList, { loading: loading, items: tasks !== null && tasks !== void 0 ? tasks : [], alternateTool: react_1.default.createElement(polaris_1.Pagination, { onNext: nextPage, hasNext: hasNextPage, onPrevious: prevPage, hasPrevious: hasPrevPage }), filterControl: filters ? (react_1.default.createElement(polaris_1.Filters, { filters: filters, hideQueryField: true, appliedFilters: appliedFilters, onQueryChange: () => { }, onQueryClear: () => { }, onClearAll: () => { } })) : undefined, resourceName: { singular: "task", plural: "tasks" }, renderItem: (task) => {
                    return (react_1.default.createElement(polaris_1.ResourceItem, { id: task.id, onClick: () => viewTask(task.ref) },
                        react_1.default.createElement("div", { className: "taskify-task-list__row" },
                            react_1.default.createElement(polaris_1.Stack, { alignment: "center" },
                                react_1.default.createElement("p", null, task.taskDefinitionName),
                                react_1.default.createElement(StatusBadge_1.StatusBadge, { status: task.status }),
                                task.createdAt && (react_1.default.createElement(polaris_1.TextStyle, { variation: "subdued" }, date_fns_1.formatDistanceToNow(task.createdAt.toDate(), {
                                    addSuffix: true,
                                })))))));
                } }))));
};
exports.TaskList = TaskList;
const TABS = [
    {
        id: "all",
        content: "All tasks",
    },
    {
        id: taskify_shared_1.TaskStatus.FAILED,
        content: "Failed",
    },
    {
        id: taskify_shared_1.TaskStatus.TIMEOUT,
        content: "Timeout",
    },
];
function disambiguateLabel(key, value) {
    const valueArray = "string" === typeof value ? [value] : value;
    switch (key) {
        case "taskType":
            return valueArray.map((val) => `Type: ${val}`).join(", ");
        default:
            return valueArray.join("");
    }
}
